# Class: name
#
#
class baruwa {
	include uwsgi
	include nginx
	include exim
	include cron
	require baruwa::db
	if $baruwa_pgsql_host == '127.0.0.1' {
	    include sphinx
	    include pgbouncer
	    include postgresql::server
	}

    $app_uuid = uuid($baruwa_web_vhost)
    $session_secret = random_password(25)
    $baruwa_path = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "/usr/lib/python2.7/dist-packages/baruwa",
        default => "/usr/lib/python2.6/site-packages/baruwa",
    }
    
    $cracklib_package = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "cracklib-runtime",
        default => "cracklib",
    }
    
    if $operatingsystem in ['Ubuntu', 'Debian'] {
        package { "python-repoze.who":
            ensure => installed,
        }
        package { "$cracklib_package":
            ensure => installed,
        }
        package { "baruwa":
            ensure => installed,
            require => Package["python-repoze.who"],
        }
    }else{
        package { "$cracklib_package":
            ensure => installed,
        }
        package { "baruwa":
            ensure => installed,
        }
    }

    package { "vim":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "vim",
            default => "vim-enhanced",
        },
        ensure => installed,
    }

    service { "baruwa":
        enable     => true,
        ensure     => running,
        hasrestart => true,
        hasstatus  => true,
        require => [Package["baruwa"], Service["crond"]],
    }

    user { "baruwa":
        groups => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => ["baruwa", "Debian-exim"],
            default => ["baruwa", "exim"],
        },
        require => [Package["exim"], Package["baruwa"], Exec["fix-amqp-dep"]],
    }
    
    if $baruwa_pgsql_host == '127.0.0.1' {
        package { "baruwa-sphinx":
            ensure => installed,
        }
    }

    file { "/etc/baruwa/production.ini":
        content => template("baruwa/production.ini.erb"),
        require => Package["baruwa"],
        notify => [Service["baruwa"], Service["uwsgi"]],
    }

    file { "/etc/nginx/conf.d/default.conf":
        content => template("baruwa/nginx.conf.erb"),
        require => [Package["baruwa"], Package["nginx"]],
        notify => Service["nginx"],
    }

    file { "/etc/uwsgi/baruwa.ini":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "/etc/uwsgi/apps-enabled/production.ini",
            default => "/etc/uwsgi/baruwa.ini",
        },
        target => "/etc/baruwa/production.ini",
        require => [File["/etc/baruwa/production.ini"], Package["uwsgi"]],
        ensure => link,
        notify => Service["uwsgi"],
    }

    file { "/etc/profile.d/baruwa.sh":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        content => template("baruwa/baruwa.sh.erb"),
        require => Package["vim"],
    }

    if $baruwa_pgsql_host == '127.0.0.1' {
        exec { "initial-indexing":
            command => "indexer --all --rotate",
            require => Exec["populate-db"],
            unless => $operatingsystem ? {
                /(?i:Debian|Ubuntu)/ => "ls /var/lib/sphinxsearch/messagesdelta.spa",
                default => "ls /var/lib/sphinx/messagesdelta.spa",
            },
            user => $operatingsystem ? {
                /(?i:Debian|Ubuntu)/ => "sphinxsearch",
                default => "sphinx",
            },
        }
    }

    $sqlcheck = "'\\dt' | grep bearer_tokens"
    exec { "populate-db":
        command => "paster setup-app /etc/baruwa/production.ini",
        path => "/bin:/usr/bin",
        require => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => [File["/etc/baruwa/production.ini"], Service["pgbouncer"], Service["postgresql"]],
            default => [File["/etc/baruwa/production.ini"], Package["postgresql"]],
        },
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c $sqlcheck",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c $sqlcheck",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }

    $sacheck = "\"SELECT id FROM sarules WHERE id='AWL'\" | grep AWL"
    exec { "update-sa-rules":
        command => "paster update-sa-rules /etc/baruwa/production.ini",
        path => "/usr/bin:/bin",
        require => Exec["populate-db"],
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c $sacheck",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c $sacheck",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }
    
    $sqlcheck4 = "\"SELECT internal FROM configurations WHERE internal IN ('nonforgingviruses','allowpasswordprotectedarchives','checkfilenamesinpasswordprotectedarchives')\" \
                    |egrep -v 'nonforgingviruses|allowpasswordprotectedarchives|checkfilenamesinpasswordprotectedarchives' >/dev/null"
    postgresql::executesql{"remove-incorrect-config.sql":
        username => $baruwa_pgsql_user,
		password => $baruwa_pgsql_passwd,
		database => $baruwa_pgsql_db,
		sql => template("baruwa/remove-incorrect-config.sql.erb"),
		sqlcheck => $sqlcheck4,
		require => Exec["populate-db"],
	}

    $sqlcheck5 = "'\\dS messages'|grep -v '\"ix_messages_messageid\" UNIQUE,' >/dev/null"
    postgresql::executesql{"upgrade202.sql":
        username => $baruwa_pgsql_user,
		password => $baruwa_pgsql_passwd,
		database => $baruwa_pgsql_db,
		sql => template("baruwa/upgrade202.sql.erb"),
		sqlcheck => $sqlcheck5,
		require => Exec["runsql-remove-incorrect-config.sql"],
	}
    
	$sqlcheck3 = "'\\dS relaysettings'|grep -w description"
    postgresql::executesql{"upgrade205.sql":
        username => $baruwa_pgsql_user,
		password => $baruwa_pgsql_passwd,
		database => $baruwa_pgsql_db,
		sql => template("baruwa/upgrade205.sql.erb"),
		sqlcheck => $sqlcheck3,
		require => Exec["runsql-upgrade202.sql"],
	}
	
	$sqlcheck6 = "'\\dS maildomains'|grep 'virus_checks_at_smtp'"
    postgresql::executesql{"baruwa-upgrade206.sql":
        username => $baruwa_pgsql_user,
		password => $baruwa_pgsql_passwd,
		database => $baruwa_pgsql_db,
		sql => template("baruwa/upgrade206.sql.erb"),
		sqlcheck => $sqlcheck6,
		require => Exec["runsql-upgrade205.sql"],
	}

    exec { "fix-missing-alldomains-view":
        command => "paster setup-app /etc/baruwa/production.ini",
        require => Exec["runsql-upgrade206.sql"],
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c '\\dv' | grep alldomains",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c $sqlcheck",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }

    exec { "check-admin-password":
        command => "echo \"${baruwa_admin_passwd}\" | cracklib-check | grep OK",
        require => [Package["$cracklib_package"], Exec["runsql-upgrade206.sql"]],
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c 'SELECT username FROM users'|grep ${baruwa_admin_user}",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c 'SELECT username FROM users'|grep ${baruwa_admin_user}",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }

    exec { "create-admin-user":
        command => "paster create-admin-user /etc/baruwa/production.ini \
                    -u ${baruwa_admin_user} -p \"${baruwa_admin_passwd}\" \
                    -e ${baruwa_admin_email} -t ${baruwa_timezone}",
        path => "/bin:/usr/bin",
        require => Exec["check-admin-password"],
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c 'SELECT username FROM users'|grep ${baruwa_admin_user}",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c 'SELECT username FROM users'|grep ${baruwa_admin_user}",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }
    
    exec { "fix-rules-template":
        command => 'sed -e \'s/*@${alias.name}%reports-base%/*@${alias.name} %reports-base%/\' \
                    -i /usr/lib/python2.6/site-packages/baruwa/templates/mailscanner/sendererrorreport.rules',
        unless => 'grep \'*@${alias.name} %reports-base%/${domain.language}\' \
                    /usr/lib/python2.6/site-packages/baruwa/templates/mailscanner/sendererrorreport.rules',
        require => [Exec["fix-missing-alldomains-view"], Exec["create-admin-user"]],
    }

    exec { "create-ms-rulesets":
        command => "paster update-rulesets /etc/baruwa/production.ini",
        path => "/bin:/usr/bin",
        require => Exec["fix-rules-template"],
        unless => "ls -l /etc/MailScanner/baruwa/rules/spam.actions.rules",
    }

    exec { "fix-domain-edit":
        command => "sed -e 's/get_organizations(), session)/get_organizations, session)/' \
                    -i /usr/lib/python2.6/site-packages/baruwa/controllers/domains.py",
        unless => "grep 'get_organizations, session)' /usr/lib/python2.6/site-packages/baruwa/controllers/domains.py",
        notify => Service["uwsgi"],
    }

    exec { "fix-amqp-dep":
        command => "sed -i '8 a exclude=python-amqp' /etc/yum.repos.d/epel.repo",
        unless => "grep 'exclude=python-amqp' /etc/yum.repos.d/epel.repo",
    }
}